@@ -1,35 +1,14 @@
-import datetime
 from flask import Flask, request, redirect, url_for
 from flaskext.sqlalchemy import SQLAlchemy
-from flaskext.auth import Auth, AuthUser, login_required, logout
+from flaskext.auth import Auth, login_required, logout
+from flaskext.auth.models.sa import get_user_class
 
 app = Flask(__name__)
 app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:////tmp/test.db'
 db = SQLAlchemy(app)
 auth = Auth(app, login_url_name='index')
 
-def now():
-    return datetime.datetime.now()
-
-class User(db.Model, AuthUser):
-    """
-    Implementation of User for SQLAlchemy.
-    """
-    id = db.Column(db.Integer, primary_key=True)
-    username = db.Column(db.String(80), unique=True, nullable=False)
-    password = db.Column(db.String(120), nullable=False)
-    salt = db.Column(db.String(80))
-    role = db.Column(db.String(80))
-    created = db.Column(db.DateTime(), default=now)
-    modified = db.Column(db.DateTime())
-
-    def __init__(self, *args, **kwargs):
-        super(User, self).__init__(*args, **kwargs)
-        password = kwargs.get('password')
-        if password is not None and not self.id:
-            self.created = datetime.datetime.utcnow()
-            # Initialize and encrypt password before first save.
-            self.set_and_encrypt_password(password)
+User = get_user_class(db.Model)
 
 @login_required()
 def admin():
@@ -71,10 +50,10 @@ def user_create():
         '''
 
 def logout_view():
-    user = logout()
-    if user is None:
+    user_data = logout()
+    if user_data is None:
         return 'No user to log out.'
-    return 'Logged out user {0}.'.format(user.username)
+    return 'Logged out user {0}.'.format(user_data['username'])
 
 # URLs
 app.add_url_rule('/', 'index', index, methods=['GET', 'POST'])
